%define name	bash-completion
%define version 20090212
%define release %mkrel 1

Name:		%{name}
Version:	%{version}
Release:	%{release}
Summary:	Programmable completion for bash
Group:		Shells
License:	GPL
URL:		http://www.caliban.org/bash/
Source0:	http://www.caliban.org/files/bash/%{name}-%{version}.tar.bz2
# configuration: allow to disable slow remote scp completion
Patch5:		bash-completion-20090202-scp-remote.patch
# configuration: allow to disable slow rpm database completion
Patch8:		bash-completion-20090202-rpm-database.patch
# configuration: make ~/.bash_completion sourced by profile scriptlet
Patch10:	bash-completion-20050121-disable-user-completion.patch
Patch28:	bash-completion-20060301-better-screen-completion.patch
Patch30:	bash-completion-20090108-externalise-openssl-completion.patch
Patch31:	bash-completion-20090108-externalise-mkinitrd-completion.patch
Requires:	bash >= 2.05
BuildArch:	noarch
BuildRoot:	%{_tmppath}/%{name}-%{version}

%description
bash-completion is a collection of shell functions that take advantage of
the programmable completion feature of bash.

%prep
%setup -q -n bash-completion
%patch5 -p 1
%patch8 -p 1
%patch10
%patch28
%patch30 -p 1
%patch31 -p 1

%install
rm -rf %{buildroot}
mkdir -p %{buildroot}%_sysconfdir/bash_completion.d
install -m 644 bash_completion %{buildroot}%_sysconfdir

install -d -m 755 %{buildroot}%{_datadir}/bash-completion
install -m 644 contrib/* %{buildroot}%{_datadir}/bash-completion
install -m 644 to_review/* %{buildroot}%{_datadir}/bash-completion

mkdir -p %{buildroot}%_sysconfdir/profile.d/
cat <<'EOF' >> %{buildroot}%_sysconfdir/profile.d/20bash-completion.sh
#!/bin/sh
# system-wide activation
if [ "$PS1" ]  && [ -n "$BASH" ]; then
    # source system wide config file
	. %_sysconfdir/sysconfig/bash-completion
    # source user config file if available,
    if [ -f $HOME/.bash_completion ]; then
        . $HOME/.bash_completion
    fi

    if [ -n "$ENABLE_BASH_COMPLETION" ]; then
        . %_sysconfdir/bash_completion
    fi
fi
EOF

mkdir -p %{buildroot}%_sysconfdir/sysconfig
cat <<'EOF' >> %{buildroot}%_sysconfdir/sysconfig/bash-completion
# bash completion global configuration

# enable bash completion
ENABLE_BASH_COMPLETION=1
# enable remote cvs completion
COMP_CVS_REMOTE=
# enable remote scp completion
COMP_SCP_REMOTE=
# enable configure arguments completion
COMP_CONFIGURE_HINTS=
# enable tar archive internal path completion
COMP_TAR_INTERNAL_PATHS=
# enable wireless uid completion
COMP_IWLIST_SCAN=
# enable installed packages completion
COMP_RPM_DATABASE=
EOF

mkdir -p %{buildroot}%_sysconfdir/skel
cat <<'EOF' >> %{buildroot}%_sysconfdir/skel/.bash_completion
# bash completion local configuration

# enable bash completion
#ENABLE_BASH_COMPLETION=1
# enable remote cvs completion
#COMP_CVS_REMOTE=
# enable remote scp completion
#COMP_SCP_REMOTE=
# enable configure arguments completion
#COMP_CONFIGURE_HINTS=
# enable tar archive internal path completion
#COMP_TAR_INTERNAL_PATHS=
# enable wireless uid completion
#COMP_IWCONFIG_SCAN=
# enable installed packages completion
#COMP_RPM_DATABASE=
EOF

cat > README.install.urpmi <<EOF
Mandriva RPM specific notes

Programmable bash completion except for slow completions is enabled
by default. These settings can be changed system-wide in
/etc/sysconfig/bash-completion. Users may override these settings in
their ~/.bash_completion files. New users get a skeleton
configuration file automatically, while existing users can copy
/etc/skel/.bash_completion into their home directories if they want
to edit their completion settings.
EOF

%triggerin -- bittorent > 5.2.2-3mdv2009.1
ln -sf %{_datadir}/bash-completion/bittorent %{_sysconfdir}/bash_completion.d

%triggerun -- bittorent > 5.2.2-3mdv2009.1
if [ $2 = 0 ]; then
    rm -f %{_sysconfdir}/bash_completion.d/bittorent
fi

%triggerin -- bluez > 4.27-1mdv2009.1
ln -sf %{_datadir}/bash-completion/bluez-utils %{_sysconfdir}/bash_completion.d

%triggerun -- bluez > 4.27-1mdv2009.1
if [ $2 = 0 ]; then
    rm -f %{_sysconfdir}/bash_completion.d/bluez-utils
fi

%triggerin -- bridge-utils > 1.4-2mdv2009.1
ln -sf %{_datadir}/bash-completion/brctl %{_sysconfdir}/bash_completion.d

%triggerun -- bridge-utils > 1.4-2mdv2009.1
if [ $2 = 0 ]; then
    rm -f %{_sysconfdir}/bash_completion.d/brctl
fi

%triggerin -- cksfv
ln -sf %{_datadir}/bash-completion/cksfv %{_sysconfdir}/bash_completion.d

%triggerun -- cksfv
if [ $2 = 0 ]; then
    rm -f %{_sysconfdir}/bash_completion.d/cksfv
fi

%triggerin -- clisp
ln -sf %{_datadir}/bash-completion/clisp %{_sysconfdir}/bash_completion.d

%triggerun -- clisp
if [ $2 = 0 ]; then
    rm -f %{_sysconfdir}/bash_completion.d/clisp
fi

%triggerin -- cowsay > 3.03-15mdv2009.1
ln -sf %{_datadir}/bash-completion/cowsay %{_sysconfdir}/bash_completion.d

%triggerun -- cowsay > 3.03-15mdv2009.1
if [ $2 = 0 ]; then
    rm -f %{_sysconfdir}/bash_completion.d/cowsay
fi

%triggerin -- dsniff > 2.4-0.b2.8mdv2009.1
ln -sf %{_datadir}/bash-completion/dsniff %{_sysconfdir}/bash_completion.d

%triggerun -- dsniff > 2.4-0.b2.8mdv2009.1
if [ $2 = 0 ]; then
    rm -f %{_sysconfdir}/bash_completion.d/dsniff
fi

%triggerin -- freeciv > 2.1.8-1mdv2009.1
ln -sf %{_datadir}/bash-completion/freeciv %{_sysconfdir}/bash_completion.d

%triggerun -- freeciv > 2.1.8-1mdv2009.1
if [ $2 = 0 ]; then
    rm -f %{_sysconfdir}/bash_completion.d/freeciv
fi

%triggerin -- gnupg2
ln -sf %{_datadir}/bash-completion/gpg2 %{_sysconfdir}/bash_completion.d

%triggerun -- gnupg2
if [ $2 = 0 ]; then
    rm -f %{_sysconfdir}/bash_completion.d/gpg2
fi

%triggerin -- gkrellm > 2.3.2-1mdv2009.1
ln -sf %{_datadir}/bash-completion/gkrellm %{_sysconfdir}/bash_completion.d

%triggerun -- gkrellm > 2.3.2-1mdv2009.1
if [ $2 = 0 ]; then
    rm -f %{_sysconfdir}/bash_completion.d/gkrellm
fi

%triggerin -- heimdal-workstation
ln -sf %{_datadir}/bash-completion/heimdal %{_sysconfdir}/bash_completion.d

%triggerun -- heimdal-workstation
if [ $2 = 0 ]; then
    rm -f %{_sysconfdir}/bash_completion.d/heimdal
fi

%triggerin -- unixODBC
ln -sf %{_datadir}/bash-completion/isql %{_sysconfdir}/bash_completion.d

%triggerun -- unixODBC
if [ $2 = 0 ]; then
    rm -f %{_sysconfdir}/bash_completion.d/isql
fi

%triggerin -- ldapvi > 1.7-6mdv2009.0
ln -sf %{_datadir}/bash-completion/ldapvi %{_sysconfdir}/bash_completion.d

%triggerun -- ldavpi > 1.7-6mdv2009.0
if [ $2 = 0 ]; then
    rm -f %{_sysconfdir}/bash_completion.d/ldapvi
fi

%triggerin -- lilypond > 2.12.2-1mdv2009.1
ln -sf %{_datadir}/bash-completion/lilypond %{_sysconfdir}/bash_completion.d

%triggerun -- lilypond > 2.12.2-1mdv2009.1
if [ $2 = 0 ]; then
    rm -f %{_sysconfdir}/bash_completion.d/lilypond
fi

%triggerin -- lzop
ln -sf %{_datadir}/bash-completion/lzop %{_sysconfdir}/bash_completion.d

%triggerun -- lzop
if [ $2 = 0 ]; then
    rm -f %{_sysconfdir}/bash_completion.d/lzop
fi

%triggerin -- mcrypt > 2.6.8-1mdv2009.1
ln -sf %{_datadir}/bash-completion/mcrypt %{_sysconfdir}/bash_completion.d

%triggerun -- mcrypt > 2.6.8-1mdv2009.1
if [ $2 = 0 ]; then
    rm -f %{_sysconfdir}/bash_completion.d/mcrypt
fi

%triggerin -- minicom > 2.3-5mdv2009.1
ln -sf %{_datadir}/bash-completion/minicom %{_sysconfdir}/bash_completion.d

%triggerun -- minicom > 2.3-5mdv2009.1
if [ $2 = 0 ]; then
    rm -f %{_sysconfdir}/bash_completion.d/minicom
fi

%triggerin -- monodevelop
ln -sf %{_datadir}/bash-completion/monodevelop %{_sysconfdir}/bash_completion.d

%triggerun -- monodevelop
if [ $2 = 0 ]; then
    rm -f %{_sysconfdir}/bash_completion.d/monodevelop
fi

%triggerin -- munin-node > 1.3.4-4mdv2009.1
ln -sf %{_datadir}/bash-completion/munin-node %{_sysconfdir}/bash_completion.d

%triggerun -- munin-node > 1.3.4-4mdv2009.1
if [ $2 = 0 ]; then
    rm -f %{_sysconfdir}/bash_completion.d/munin-node
fi

%triggerin -- mkinitrd > 6.0.63-9mnb2
ln -sf %{_datadir}/bash-completion/mkinitrd %{_sysconfdir}/bash_completion.d

%triggerun -- mkinitrd > 6.0.63-9mnb2
if [ $2 = 0 ]; then
    rm -f %{_sysconfdir}/bash_completion.d/mkinitrd
fi

%triggerin -- net-tools > 1.60-29mdv2009.1
ln -sf %{_datadir}/bash-completion/net-tools %{_sysconfdir}/bash_completion.d

%triggerun -- net-tools > 1.60-29mdv2009.1
if [ $2 = 0 ]; then
    rm -f %{_sysconfdir}/bash_completion.d/net-tools
fi

%triggerin -- msynctool > 0.22-7mdv2009.0
ln -sf %{_datadir}/bash-completion/msynctool %{_sysconfdir}/bash_completion.d

%triggerun -- msynctool > 0.22-7mdv2009.0
if [ $2 = 0 ]; then
    rm -f %{_sysconfdir}/bash_completion.d/msynctool
fi

%triggerin -- nfs-utils > 1:1.1.4-2mdv2009.1
ln -sf %{_datadir}/bash-completion/rpcdebug %{_sysconfdir}/bash_completion.d

%triggerun -- nfs-utils > 1:1.1.4-2mdv2009.1
if [ $2 = 0 ]; then
    rm -f %{_sysconfdir}/bash_completion.d/rpcdebug
fi

%triggerin -- openldap-clients > 2.4.13-4mdv2009.1
ln -sf %{_datadir}/bash-completion/openldap %{_sysconfdir}/bash_completion.d

%triggerun -- openldap-clients > 2.4.13-4mdv2009.1
if [ $2 = 0 ]; then
    rm -f %{_sysconfdir}/bash_completion.d/openldap
fi

%triggerin -- openssh-clients
ln -sf %{_datadir}/bash-completion/ssh %{_sysconfdir}/bash_completion.d

%triggerun -- openssh-clients
if [ $2 = 0 ]; then
    rm -f %{_sysconfdir}/bash_completion.d/ssh
fi

%triggerin -- openssl > 0.9.8i-4mdv2009.1
ln -sf %{_datadir}/bash-completion/openssl %{_sysconfdir}/bash_completion.d

%triggerun -- openssl > 0.9.8i-4mdv2009.1
if [ $2 = 0 ]; then
    rm -f %{_sysconfdir}/bash_completion.d/openssl
fi

%triggerin -- perl-CPANPLUS > 0.84-3mdv2009.1
ln -sf %{_datadir}/bash-completion/cpan2dist %{_sysconfdir}/bash_completion.d

%triggerun -- perl-CPANPLUS > 0.84-3mdv2009.1
if [ $2 = 0 ]; then
    rm -f %{_sysconfdir}/bash_completion.d/cpan2dist
fi

%triggerin -- qemu > 0.9.1-0.r5137.1mdv2009.0
ln -sf %{_datadir}/bash-completion/qemu %{_sysconfdir}/bash_completion.d

%triggerun -- qemu > 0.9.1-0.r5137.1mdv2009.0
if [ $2 = 0 ]; then
    rm -f %{_sysconfdir}/bash_completion.d/qemu
fi

%triggerin -- quota > 3.16-4mdv2009.1
ln -sf %{_datadir}/bash-completion/quota-tools %{_sysconfdir}/bash_completion.d

%triggerun -- quota > 3.16-4mdv2009.1
if [ $2 = 0 ]; then
    rm -f %{_sysconfdir}/bash_completion.d/quota-tools
fi

%triggerin -- rdesktop > 1.6.0-6mdv2009.1
ln -sf %{_datadir}/bash-completion/rdesktop %{_sysconfdir}/bash_completion.d

%triggerun -- rdesktop > 1.6.0-6mdv2009.1
if [ $2 = 0 ]; then
    rm -f %{_sysconfdir}/bash_completion.d/rdesktop
fi

%triggerin -- rpmcheck > 0.0.2368-7mdv2009.1
ln -sf %{_datadir}/bash-completion/rpmcheck %{_sysconfdir}/bash_completion.d

%triggerun -- rpmcheck > 0.0.2368-7mdv2009.1
if [ $2 = 0 ]; then
    rm -f %{_sysconfdir}/bash_completion.d/rpmcheck
fi

%triggerin -- samba-clients > 3.2.7-1mdv2009.1
ln -sf %{_datadir}/bash-completion/samba %{_sysconfdir}/bash_completion.d

%triggerun -- samba-clients > 3.2.7-1mdv2009.1
if [ $2 = 0 ]; then
    rm -f %{_sysconfdir}/bash_completion.d/samba
fi

%triggerin -- sitecopy
ln -sf %{_datadir}/bash-completion/sitecopy %{_sysconfdir}/bash_completion.d

%triggerun -- sitecopy
if [ $2 = 0 ]; then
    rm -f %{_sysconfdir}/bash_completion.d/sitecopy
fi

%triggerin -- smartmontools > 5.38-3mdv2009.0
ln -sf %{_datadir}/bash-completion/smartctl %{_sysconfdir}/bash_completion.d

%triggerun -- smartmontools > 5.38-3mdv2009.0
if [ $2 = 0 ]; then
    rm -f %{_sysconfdir}/bash_completion.d/smartctl
fi

%triggerin -- strace > 4.5.18-1mdv2009.1
ln -sf %{_datadir}/bash-completion/strace %{_sysconfdir}/bash_completion.d

%triggerun -- strace > 4.5.18-1mdv2009.1
if [ $2 = 0 ]; then
    rm -f %{_sysconfdir}/bash_completion.d/strace
fi

%triggerin -- tightvnc > 1.3.9-17mdv2009.1
ln -sf %{_datadir}/bash-completion/vncviewer %{_sysconfdir}/bash_completion.d

%triggerun -- tightvnc > 1.3.9-17mdv2009.1
if [ $2 = 0 ]; then
    rm -f %{_sysconfdir}/bash_completion.d/vncviewer
fi

%triggerin -- vpnc > 0.5.3-1mdv2009.1
ln -sf %{_datadir}/bash-completion/vpnc %{_sysconfdir}/bash_completion.d

%triggerun -- vpnc 0.5.3-1mdv2009.1
if [ $2 = 0 ]; then
    rm -f %{_sysconfdir}/bash_completion.d/vpnc
fi

%triggerin -- unace
ln -sf %{_datadir}/bash-completion/unace %{_sysconfdir}/bash_completion.d

%triggerun -- unace
if [ $2 = 0 ]; then
    rm -f %{_sysconfdir}/bash_completion.d/unace
fi

%triggerin -- unrar > 3.80-1mdv2009.1
ln -sf %{_datadir}/bash-completion/unrar %{_sysconfdir}/bash_completion.d

%triggerun -- unrar > 3.80-1mdv2009.1
if [ $2 = 0 ]; then
    rm -f %{_sysconfdir}/bash_completion.d/unrar
fi

%triggerin -- xz
ln -sf %{_datadir}/bash-completion/lzma %{_sysconfdir}/bash_completion.d

%triggerun -- xz
if [ $2 = 0 ]; then
    rm -f %{_sysconfdir}/bash_completion.d/lzma
fi

%triggerin -- xen > 3.3.1-1mdv2009.1
ln -sf %{_datadir}/bash-completion/xm %{_sysconfdir}/bash_completion.d

%triggerun -- xen > 3.3.1-1mdv2009.1
if [ $2 = 0 ]; then
    rm -f %{_sysconfdir}/bash_completion.d/xm
fi

%clean
rm -rf %{buildroot}

%files
%defattr(-,root,root)
%doc README README.*.urpmi TODO
%{_sysconfdir}/bash_completion
%{_sysconfdir}/bash_completion.d
%{_sysconfdir}/profile.d/20bash-completion.sh
%{_datadir}/bash-completion
%config(noreplace) %{_sysconfdir}/sysconfig/bash-completion
%config(noreplace) %{_sysconfdir}/skel/.bash_completion




%changelog
* Thu Feb 12 2009 Guillaume Rousse <guillomovitch@mandriva.org> 20090212-1mdv2009.1
+ Revision: 339929
- new snapshot
- drop merged patches

* Mon Feb 09 2009 Guillaume Rousse <guillomovitch@mandriva.org> 20090209-1mdv2009.1
+ Revision: 339014
- new release
- drop _command completion patch, it breaks strace completion, but fix sudo and other similar command (bug #47517)

* Wed Feb 04 2009 Guillaume Rousse <guillomovitch@mandriva.org> 20090204-1mdv2009.1
+ Revision: 337605
- new snapshot

* Tue Feb 03 2009 Guillaume Rousse <guillomovitch@mandriva.org> 20090203-1mdv2009.1
+ Revision: 337206
- new snapshot (more patches merged)
- don't install additional completion as documentation, but in %%_datadir/bash-completion
- use trigger to symlink them under %%_sysconfdir/bash_completion.d
- drop old upgrade README

* Mon Feb 02 2009 Guillaume Rousse <guillomovitch@mandriva.org> 20090202-1mdv2009.1
+ Revision: 336665
- new snapshot

* Tue Jan 13 2009 Guillaume Rousse <guillomovitch@mandriva.org> 20090108-2mdv2009.1
+ Revision: 328902
- openssl and mkinitrd completions are now shipped in respective packages
- fix PCI id completion

* Fri Jan 09 2009 Guillaume Rousse <guillomovitch@mandriva.org> 20090108-1mdv2009.1
+ Revision: 327527
- new version
- rediff patches 1, 5, 8, 20, 23, 24, 25
- drop patch 2 (alias completion)

* Wed Aug 06 2008 Thierry Vignaud <tvignaud@mandriva.com> 20060301-23mdv2009.0
+ Revision: 264328
- rebuild early 2009.0 package (before pixel changes)

* Mon Apr 14 2008 Guillaume Rousse <guillomovitch@mandriva.org> 20060301-22mdv2009.0
+ Revision: 192686
- rediff patch 5 to fix remote host completion with scp

* Wed Mar 19 2008 Per Øyvind Karlsen <peroyvind@mandriva.org> 20060301-21mdv2008.1
+ Revision: 188796
- /usr/lib/rpm/mandriva/macros is gone, don't try look after macros in it

* Wed Mar 05 2008 Per Øyvind Karlsen <peroyvind@mandriva.org> 20060301-20mdv2008.1
+ Revision: 180166
- be sure to read all macros from /etc/rpm/macros.d/*.macros & /usr/lib/rpm/mandriva/macros (P29)
- add mp2 format as well for mplayer completion

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot

  + Thierry Vignaud <tvignaud@mandriva.com>
    - kill re-definition of %%buildroot on Pixel's request

* Sat Dec 08 2007 Guillaume Rousse <guillomovitch@mandriva.org> 20060301-19mdv2008.1
+ Revision: 116509
- document configuration settings
- non-executable and versioned profile scriptlet
- uniformize patches format
- better screen completion
  fix getent completion

* Wed Sep 19 2007 Per Øyvind Karlsen <peroyvind@mandriva.org> 20060301-18mdv2008.0
+ Revision: 91004
- fix typo in P25 that broken tar lzma completion

* Wed Sep 12 2007 Anssi Hannula <anssi@mandriva.org> 20060301-17mdv2008.0
+ Revision: 84667
- update documentation, and do not show them on every upgrade

* Tue Sep 04 2007 Götz Waschk <waschk@mandriva.org> 20060301-16mdv2008.0
+ Revision: 79138
- improve rpm suggests patch

* Mon Sep 03 2007 Götz Waschk <waschk@mandriva.org> 20060301-15mdv2008.0
+ Revision: 78543
- add suggests option to rpm completion

* Mon Aug 27 2007 Guillaume Rousse <guillomovitch@mandriva.org> 20060301-14mdv2008.0
+ Revision: 71784
- don't call wrapped command completion twice (fix #32795)

* Thu Jul 19 2007 Guillaume Rousse <guillomovitch@mandriva.org> 20060301-13mdv2008.0
+ Revision: 53705
- make use configuration override system configuration (fix #31833)

* Sun Jul 15 2007 Per Øyvind Karlsen <peroyvind@mandriva.org> 20060301-12mdv2008.0
+ Revision: 52236
- add lzma support (P25)
- add mplayer completion for .flv (flash video), .xvid & .divx (P24)

* Fri Jun 15 2007 Guillaume Rousse <guillomovitch@mandriva.org> 20060301-11mdv2008.0
+ Revision: 39972
- better perl completion


* Mon Mar 05 2007 Guillaume Rousse <guillomovitch@mandriva.org> 20060301-10mdv2007.0
+ Revision: 133084
- add bibtex completion (#29056)

* Wed Feb 14 2007 Guillaume Rousse <guillomovitch@mandriva.org> 20060301-9mdv2007.1
+ Revision: 121134
- cdrkit completion

* Mon Jan 22 2007 Guillaume Rousse <guillomovitch@mandriva.org> 20060301-8mdv2007.1
+ Revision: 111626
- fix command completion for command without completion function

* Sun Jan 14 2007 Guillaume Rousse <guillomovitch@mandriva.org> 20060301-7mdv2007.1
+ Revision: 108796
- better completion for command accepting another command as argument

* Fri Dec 08 2006 Guillaume Rousse <guillomovitch@mandriva.org> 20060301-6mdv2007.1
+ Revision: 92220
- add forgotten kernel completion patch, needed by dkms completion
- Import bash-completion

* Tue Sep 05 2006 Guillaume Rousse <guillomovitch@mandriva.org> 20060301-5mdv2007.0
- fix .bash_completion file (COMP_IWCONFIG_SCAN -> COMP_IWLIST_SCAN)

* Tue Sep 05 2006 Guillaume Rousse <guillomovitch@mandriva.org> 20060301-4mdv2007.0
- don't source old rpm files in /etc/bash_completion.d 
- merge mdv-specific informations in a single README.urpmi

* Tue Mar 28 2006 Guillaume Rousse <guillomovitch@mandriva.org> 20060301-3mdk
- drop additional = in alias completion (fix #21738)

* Sat Mar 11 2006 Götz Waschk <waschk@mandriva.org> 20060301-2mdk
- fix patch 17

* Wed Mar 01 2006 Götz Waschk <waschk@mandriva.org> 20060301-1mdk
- patch 17, add evince
- drop patches 6,13,14,15,16

* Wed Mar 01 2006 Götz Waschk <waschk@mandriva.org> 20060301-1mdk
- New release 20060301

* Wed Mar 01 2006 Guillaume Rousse <guillomovitch@mandriva.org> 20050721-5mdk
- add kdvi, dvipdf and advi to dvi file completion (fix bug #20947)

* Fri Jan 27 2006 Guillaume Rousse <guillomovitch@mandriva.org> 20050721-4mdk
- fix known_host completion with bash 3.1

* Thu Dec 22 2005 Guillaume Rousse <guillomovitch@mandriva.org> 20050721-3mdk
- fix installed package completion slowliness when used outside of rpm
  completion (thanx pterjan)
- rediff patch8

* Tue Oct 11 2005 Per Øyvind Karlsen <pkarlsen@mandriva.com> 20050721-2mdk
- fix completion for midi files ending with MID (P14)
- %%mkrel

* Sat Jul 23 2005 Guillaume Rousse <guillomovitch@mandriva.org> 20050721-1mdk 
- new version
- dropped patch 0, 6, 7, 9, 11 and 12 merged upstream

* Fri Jul 22 2005 Guillaume Rousse <guillomovitch@mandriva.org> 20050720-2mdk 
- iconv patch

* Thu Jul 21 2005 Götz Waschk <waschk@mandriva.org> 20050720-1mdk
- New release 20050720

* Thu Jul 14 2005 Guillaume Rousse <guillomovitch@mandriva.org> 20050712-1mdk 
- new release
- dropped patches 2, 3 and 4 merged upstream
- rediff patch 5, 7

* Sun Jun 26 2005 Guillaume Rousse <guillomovitch@mandriva.org> 20050121-8mdk 
- mc completion patch

* Fri Jun 24 2005 Guillaume Rousse <guillomovitch@mandriva.org> 20050121-7mdk 
- fix ssh aliases completion

* Tue Jun 14 2005 Guillaume Rousse <guillomovitch@mandriva.org> 20050121-6mdk 
- user config file is ~/.bash_completion, not ~/.bash-completion

* Tue Jun 14 2005 Guillaume Rousse <guillomovitch@mandriva.org> 20050121-5mdk 
- rework activation procedure again
- fix lilo labels completion

* Thu May 19 2005 Guillaume Rousse <guillomovitch@mandriva.org> 20050121-4mdk 
- make rpm slow database completion optional
- fix mplayer options completion

* Mon May 09 2005 Guillaume Rousse <guillomovitch@mandriva.org> 20050121-3mdk 
- add a bunch of patches waiting for upstream merge (id, getent, iwconfig)
- disable all slow completion by default, including remote scp completion
- rework activation procedure
- drop README.urpmi in favor of README.mdk
- spec cleanup

* Sat Apr 02 2005 Guillaume Rousse <guillomovitch@mandrake.org> 20050121-2mdk 
- fix tcpdump & dhclient completions
- add shellbang in profile script

* Mon Jan 24 2005 Guillaume Rousse <guillomovitch@mandrake.org> 20050121-1mdk
- New release 20050121

* Thu Jan 20 2005 Goetz Waschk <waschk@linux-mandrake.com> 20050120-1mdk
- New release 20050120

* Thu Jan 13 2005 Guillaume Rousse <guillomovitch@mandrake.org> 20050112-1mdk 
- New release
- don't tag scripts as config

* Tue Jan 04 2005 Guillaume Rousse <guillomovitch@mandrake.org> 20050103-1mdk
- New release 20050103

* Fri Oct 29 2004 Guillaume Rousse <guillomovitch@mandrake.org> 20041017-1mdk 
- New release 20041017
- /etc/profile.d config file is back, but disabled
- README.urpmi

* Mon Jul 12 2004 Guillaume Rousse <guillomovitch@mandrakesoft.com> 20040711-1mdk
- New release 20040711

* Sat Jul 10 2004 Guillaume Rousse <guillomovitch@mandrake.org> 20040704-2mdk 
- no more config file in /etc/profile.d, existing users have to 
  explicitely source /etc/bash_completion from their .bashrc now

* Mon Jul 05 2004 Guillaume Rousse <guillomovitch@mandrakesoft.com> 20040704-1mdk
- New release 20040704

* Thu May 27 2004 Götz Waschk <waschk@linux-mandrake.com> 20040526-1mdk
- fix URL
- New release 20040526

* Thu Apr 01 2004 Guillaume Rousse <guillomovitch@mandrake.org> 20040331-1mdk
- new version
- dropped mkisofs patch (merged upstream)

